Documentation
¶
Index ¶
- type ImageTag
- type Matrix
- type TagStore
- func (reg *TagStore) AddImage(fullTag string) error
- func (reg *TagStore) Flatten() []string
- func (reg *TagStore) FlattenWithOptions(includeNextTag bool) interface{}
- func (reg *TagStore) GetImage(name, baseTag string) (*ImageTag, bool)
- func (reg *TagStore) GetJSON(includeNextTag bool) (string, error)
- func (reg *TagStore) PatchImage(name, baseTag string) (string, bool)
- func (reg *TagStore) PrintTable(includeNextTag bool) (string, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ImageTag ¶
type ImageTag struct {
Name string `json:"name"`
BaseTag string `json:"baseTag"`
PatchLevel int `json:"patchLevel"`
}
func NewImageTag ¶
NewImageTag parses a fully qualified image tag and creates an ImageTag struct
func (*ImageTag) GetCurrentTag ¶
func (*ImageTag) GetNextPatchTag ¶
func (*ImageTag) IncrementPatch ¶
func (it *ImageTag) IncrementPatch()
type TagStore ¶
TagStore type that only uses a map
func (*TagStore) FlattenWithOptions ¶
TODO: include tag strategy as param
func (*TagStore) PatchImage ¶
PatchImage increments the patch level for an image if it exists
Click to show internal directories.
Click to hide internal directories.